EXPORTS
	??1CDevASR@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CDevASR::~CDevASR(void)
	?Cancel@CDevASR@@QAEXXZ @ 2 NONAME ; public: void __thiscall CDevASR::Cancel(void)
	?CustomInterface@CDevASR@@QAEPAXVTUid@@@Z @ 3 NONAME ; public: void * __thiscall CDevASR::CustomInterface(class TUid)
	?E32Dll@@YAHW4TDllReason@@@Z @ 4 NONAME ; int __cdecl E32Dll(enum TDllReason)
	?EndRecSession@CDevASR@@QAEXXZ @ 5 NONAME ; public: void __thiscall CDevASR::EndRecSession(void)
	?GetEnginePropertiesL@CDevASR@@QAEXABV?$RArray@H@@AAV2@@Z @ 6 NONAME ; public: void __thiscall CDevASR::GetEnginePropertiesL(class RArray<int> const &,class RArray<int> &)
	?GetUtteranceData@CDevASR@@QAEXPAVTDes8@@AAVTTimeIntervalMicroSeconds32@@@Z @ 7 NONAME ; public: void __thiscall CDevASR::GetUtteranceData(class TDes8 *,class TTimeIntervalMicroSeconds32 &)
	?InitFrontEnd@CDevASR@@QAEXW4TRecognizerMode@@@Z @ 8 NONAME ; public: void __thiscall CDevASR::InitFrontEnd(enum TRecognizerMode)
	?InitPlayL@CDevASR@@QAEAAVTDes8@@VTTimeIntervalMicroSeconds32@@@Z @ 9 NONAME ; public: class TDes8 & __thiscall CDevASR::InitPlayL(class TTimeIntervalMicroSeconds32)
	?InitRecognizerBE@CDevASR@@QAEXAAVCSDResultSet@@@Z @ 10 NONAME ; public: void __thiscall CDevASR::InitRecognizerBE(class CSDResultSet &)
	?InitTrainBE@CDevASR@@QAEXAAVCSDModel@@@Z @ 11 NONAME ; public: void __thiscall CDevASR::InitTrainBE(class CSDModel &)
	?LoadEngineParametersL@CDevASR@@QAEXABV?$RArray@H@@0@Z @ 12 NONAME ; public: void __thiscall CDevASR::LoadEngineParametersL(class RArray<int> const &,class RArray<int> const &)
	?LoadGrammar@CDevASR@@QAEXABVCSDGrammar@@@Z @ 13 NONAME ; public: void __thiscall CDevASR::LoadGrammar(class CSDGrammar const &)
	?LoadLexicon@CDevASR@@QAEXABVCSDLexicon@@@Z @ 14 NONAME ; public: void __thiscall CDevASR::LoadLexicon(class CSDLexicon const &)
	?LoadModels@CDevASR@@QAEXABVCSDModelBank@@@Z @ 15 NONAME ; public: void __thiscall CDevASR::LoadModels(class CSDModelBank const &)
	?NewL@CDevASR@@SAPAV1@AAVMDevASRObserver@@@Z @ 16 NONAME ; public: static class CDevASR * __cdecl CDevASR::NewL(class MDevASRObserver &)
	?NewLC@CDevASR@@SAPAV1@AAVMDevASRObserver@@@Z @ 17 NONAME ; public: static class CDevASR * __cdecl CDevASR::NewLC(class MDevASRObserver &)
	?Play@CDevASR@@QAEXXZ @ 18 NONAME ; public: void __thiscall CDevASR::Play(void)
	?Record@CDevASR@@QAEXVTTimeIntervalMicroSeconds32@@@Z @ 19 NONAME ; public: void __thiscall CDevASR::Record(class TTimeIntervalMicroSeconds32)
	?SetPrioritySettings@CDevASR@@QAEXABVTMMFPrioritySettings@@@Z @ 20 NONAME ; public: void __thiscall CDevASR::SetPrioritySettings(class TMMFPrioritySettings const &)
	?StartRecSession@CDevASR@@QAEHW4TRecognizerMode@@@Z @ 21 NONAME ; public: int __thiscall CDevASR::StartRecSession(enum TRecognizerMode)
	?UnloadRule@CDevASR@@QAEXKK@Z @ 22 NONAME ; public: void __thiscall CDevASR::UnloadRule(unsigned long,unsigned long)

